﻿Imports System.Reflection
Imports Syncfusion.UI.Xaml.Charts

Class MainWindow

    Dim TestColl As New ViewModel
    Dim LineSeries As New FastStepLineBitmapSeries
    Public AnnotationPopup As New CustomPopup

    Sub New()

        ' This call is required by the designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.


        ' ADD SERIES
        With LineSeries
            .ItemsSource = TestColl.Tickers(0).Minutes
            .XBindingPath = "DateTime"
            .YBindingPath = "Close"
            .Interior = New SolidColorBrush(Color.FromArgb(255, 100, 120, 255))
            .StrokeThickness = 1
        End With
        chart.Series.Add(LineSeries)

        'ADD ANNOTATIONS
        Dim newEllipseAnnotation As New CustomEllipseAnnotation(Me)
        With newEllipseAnnotation
            .X1 = 1000
            .Y1 = TestColl.Tickers(0).Minutes(1000).Close
            .Width = 8
            .Height = 8
            .StrokeThickness = 1
            .Stroke = New SolidColorBrush(Colors.Black)
            .Foreground = New SolidColorBrush(Colors.White)
            .Fill = New SolidColorBrush(Colors.Red)
            .CoordinateUnit = CoordinateUnit.Axis
            .HorizontalAlignment = HorizontalAlignment.Center
            .VerticalAlignment = VerticalAlignment.Center

            '.ShowToolTip = True
            '.ToolTipContent = "This is an annotation tooltip test."
            '.ToolTipShowDuration = 5000
        End With
        chart.Annotations.Add(newEllipseAnnotation)

        gMain.Children.Add(AnnotationPopup)

        'SET NO ANTIALIAS
        Dim image As Image = GetPrivateField(chart, "fastRenderDevice")
        If (Not (image) Is Nothing) Then
            RenderOptions.SetBitmapScalingMode(image, BitmapScalingMode.NearestNeighbor)
        End If

    End Sub

    Private Function GetPrivateField(ByVal chart As SfChart, ByVal name As String) As Image
        Dim info As FieldInfo = chart.GetType().GetField(name, BindingFlags.Instance Or (BindingFlags.NonPublic Or BindingFlags.Public))
        If (Not (info) Is Nothing) Then
            Return CType(info.GetValue(chart), Image)
        End If
        Return Nothing
    End Function


End Class

Public Class CustomPopup
    Inherits System.Windows.Controls.Primitives.Popup

    Public sp As New StackPanel

    Sub New()

        sp.Orientation = Orientation.Vertical
        Me.Child = sp

    End Sub

    Private Sub CustomPopup_MouseLeave(sender As Object, e As MouseEventArgs) Handles Me.MouseLeave

        Console.WriteLine("CustomPopup_MouseLeave")

        Me.IsOpen = False

    End Sub
End Class


Public Class CustomEllipseAnnotation
    Inherits EllipseAnnotation

    Public MainWindow As MainWindow

    Sub New(inMainWindow As MainWindow)

        MainWindow = inMainWindow

    End Sub

    Protected Overrides Sub OnMouseEnter(e As MouseEventArgs)
        Console.WriteLine("OnMouseEnter")
    End Sub

    Protected Overrides Function ArrangeOverride(finalSize As Size) As Size

        AddHandler AnnotationElement.MouseEnter, AddressOf MouseEnter

        Return MyBase.ArrangeOverride(finalSize)
    End Function

    Private Sub MouseEnter(sender As Object, e As MouseEventArgs)
        Console.WriteLine("OnMouseEnter")

        'SET POSITION
        Dim pt As Point = e.GetPosition(CType(MainWindow.gMain, UIElement))
        MainWindow.AnnotationPopup.Placement = Primitives.PlacementMode.RelativePoint
        MainWindow.AnnotationPopup.HorizontalOffset = pt.X - 3
        MainWindow.AnnotationPopup.VerticalOffset = pt.Y - 3
        MainWindow.AnnotationPopup.HorizontalAlignment = HorizontalAlignment.Left
        MainWindow.AnnotationPopup.VerticalAlignment = VerticalAlignment.Top

        'SET CONTENT
        MainWindow.AnnotationPopup.sp.Children.Clear()

        Dim textbloc1 As New TextBlock
        textbloc1.Background = New SolidColorBrush(Colors.Yellow)
        Dim hyperlink1 As New Hyperlink
        hyperlink1.Inlines.Add("hyperlink 1")
        textbloc1.Inlines.Add(hyperlink1)
        MainWindow.AnnotationPopup.sp.Children.Add(textbloc1)

        Dim textbloc2 As New TextBlock
        textbloc2.Background = New SolidColorBrush(Colors.Yellow)
        Dim hyperlink2 As New Hyperlink
        hyperlink2.Inlines.Add("hyperlink test 2")
        textbloc2.Inlines.Add(hyperlink2)
        MainWindow.AnnotationPopup.sp.Children.Add(textbloc2)

        MainWindow.AnnotationPopup.IsOpen = True
    End Sub

    Protected Overrides Sub OnMouseLeave(e As MouseEventArgs)
        Console.WriteLine("OnMouseLeave")

    End Sub


    Private Sub CustomEllipseAnnotation_MouseLeave(sender As Object, e As MouseEventArgs) Handles Me.MouseLeave
        Console.WriteLine("CustomEllipseAnnotation_MouseLeave")

        MainWindow.AnnotationPopup.sp.Children.Clear()
        MainWindow.AnnotationPopup.IsOpen = False

    End Sub

    Private Sub CustomEllipseAnnotation_MouseDown(sender As Object, e As MouseButtonEventArgs) Handles Me.MouseDown

        Console.WriteLine("CustomEllipseAnnotation_MouseDown")



    End Sub
End Class
